abacusai.llm_artifact — AbacusAI documentation

# abacusai.llm_artifact

## Classes

`LlmArtifact` | LLM Artifact

## Module Contents

class abacusai.llm_artifact.LlmArtifact(client, llmArtifactId=None, info=None, description=None, createdAt=None, webAppDeploymentId=None, deploymentStatus=None, isLatest=None, deploymentConversationId=None, webAppProjectId=None, hasDatabase=None, hasStorage=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  LLM Artifact

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - llmArtifactId (id) – The ID of the LLM artifact

    - info (dict) – The info of the LLM artifact

    - description (str) – The description of the LLM artifact

    - createdAt (str) – The creation timestamp

    - webAppDeploymentId (id) – The ID of the associated web app deployment

    - deploymentStatus (str) – The status of the associated web app deployment

    - isLatest (bool) – Whether it is the most recent version of the artifact

    - deploymentConversationId (id) – The ID of the deployment conversation

    - webAppProjectId (id) – The ID of the web app project

    - hasDatabase (bool) – Whether the app associated with the artifact has a database

    - hasStorage (bool) – Whether the app associated with the artifact has a storage

  llm_artifact_id = None
  info = None
  description = None
  created_at = None
  web_app_deployment_id = None
  deployment_status = None
  is_latest = None
  deployment_conversation_id = None
  web_app_project_id = None
  has_database = None
  has_storage = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict